@@ -3,11 +3,17 @@ import re
 import sys
 import unicodedata
 
+from unstructured.file_utils.encoding import (
+    format_encoding_str,
+)
 from unstructured.nlp.patterns import (
     DOUBLE_PARAGRAPH_PATTERN_RE,
+    E_BULLET_PATTERN,
+    LINE_BREAK_RE,
     PARAGRAPH_PATTERN,
     PARAGRAPH_PATTERN_RE,
     UNICODE_BULLETS_RE,
+    UNICODE_BULLETS_RE_0W,
 )
 
 
@@ -62,6 +68,34 @@ def clean_ordered_bullets(text) -> str:
     return text_cl
 
 
+def group_bullet_paragraph(paragraph: str) -> list:
+    """Groups paragraphs with bullets that have line breaks for visual/formatting purposes.
+    For example:
+
+    '''○ The big red fox
+    is walking down the lane.
+
+    ○ At the end of the lane
+    the fox met a friendly bear.'''
+
+    Gets converted to
+
+    '''○ The big red fox is walking down the lane.
+    ○ At the end of the land the fox met a bear.'''
+    """
+    clean_paragraphs = []
+    # pytesseract converts some bullet points to standalone "e" characters.
+    # Substitute "e" with bullets since they are later used in partition_text
+    # to determine list element type.
+    paragraph = (re.sub(E_BULLET_PATTERN, "·", paragraph)).strip()
+
+    bullet_paras = re.split(UNICODE_BULLETS_RE_0W, paragraph)
+    for bullet in bullet_paras:
+        if bullet:
+            clean_paragraphs.append(re.sub(PARAGRAPH_PATTERN, " ", bullet))
+    return clean_paragraphs
+
+
 def group_broken_paragraphs(
     text: str,
     line_split: re.Pattern = PARAGRAPH_PATTERN_RE,
@@ -86,7 +120,6 @@ def group_broken_paragraphs(
     for paragraph in paragraphs:
         if not paragraph.strip():
             continue
-
         # NOTE(robinson) - This block is to account for lines like the following that shouldn't be
         # grouped together, but aren't separated by a double line break.
         #     Apache License
@@ -94,9 +127,9 @@ def group_broken_paragraphs(
         #     http://www.apache.org/licenses/
         para_split = line_split.split(paragraph)
         all_lines_short = all(len(line.strip().split(" ")) < 5 for line in para_split)
-
-        if UNICODE_BULLETS_RE.match(paragraph.strip()):
-            clean_paragraphs.extend(re.split(PARAGRAPH_PATTERN, paragraph))
+        # pytesseract converts some bullet points to standalone "e" characters
+        if UNICODE_BULLETS_RE.match(paragraph.strip()) or E_BULLET_PATTERN.match(paragraph.strip()):
+            clean_paragraphs.extend(group_bullet_paragraph(paragraph))
         elif all_lines_short:
             clean_paragraphs.extend([line for line in para_split if line.strip()])
         else:
@@ -105,6 +138,87 @@ def group_broken_paragraphs(
     return "\n\n".join(clean_paragraphs)
 
 
+def new_line_grouper(
+    text: str,
+    paragraph_split: re.Pattern = LINE_BREAK_RE,
+) -> str:
+    """
+    Concatenates text document that has one-line paragraph break pattern
+
+    For example,
+
+    Iwan Roberts
+    Roberts celebrating after scoring a goal for Norwich City
+    in 2004
+
+    Will be returned as:
+
+    Iwan Roberts\n\nRoberts celebrating after scoring a goal for Norwich City\n\nin 2004
+    """
+    paragraphs = paragraph_split.split(text)
+    clean_paragraphs = []
+    for paragraph in paragraphs:
+        if not paragraph.strip():
+            continue
+        clean_paragraphs.append(paragraph)
+    return "\n\n".join(clean_paragraphs)
+
+
+def blank_line_grouper(
+    text: str,
+    paragraph_split: re.Pattern = DOUBLE_PARAGRAPH_PATTERN_RE,
+) -> str:
+    """
+    Concatenates text document that has blank-line paragraph break pattern
+
+    For example,
+
+    Vestibulum auctor dapibus neque.
+
+    Nunc dignissim risus id metus.
+
+    Will be returned as:
+
+    Vestibulum auctor dapibus neque.\n\nNunc dignissim risus id metus.\n\n
+
+    """
+    return group_broken_paragraphs(text)
+
+
+def auto_paragraph_grouper(
+    text: str,
+    line_split: re.Pattern = LINE_BREAK_RE,
+    max_line_count: int = 2000,
+    threshold: float = 0.1,
+) -> str:
+    """
+    Checks the ratio of new line (\n) over the total max_line_count
+
+    If the ratio of new line is less than the threshold,
+    the document is considered a new-line grouping type
+    and return the original text
+
+    If the ratio of new line is greater than or equal to the threshold,
+    the document is considered a blank-line grouping type
+    and passed on to blank_line_grouper function
+    """
+    lines = line_split.split(text)
+    max_line_count = min(len(lines), max_line_count)
+    line_count, empty_line_count = 0, 0
+    for line in lines[:max_line_count]:
+        line_count += 1
+        if not line.strip():
+            empty_line_count += 1
+    ratio = empty_line_count / line_count
+
+    # NOTE(klaijan) - for ratio < threshold, we pass to new-line grouper,
+    # otherwise to blank-line grouper
+    if ratio < threshold:
+        return new_line_grouper(text)
+    else:
+        return blank_line_grouper(text)
+
+
 # TODO(robinson) - There's likely a cleaner was to accomplish this and get all of the
 # unicode characters instead of just the quotes. Doing this for now since quotes are
 # an issue that are popping up in the SEC filings tests
@@ -194,7 +308,8 @@ def replace_mime_encodings(text: str, encoding: str = "utf-8") -> str:
     -------
     5 w=E2=80-99s -> 5 w’s
     """
-    return quopri.decodestring(text.encode(encoding)).decode(encoding)
+    formatted_encoding = format_encoding_str(encoding)
+    return quopri.decodestring(text.encode(formatted_encoding)).decode(formatted_encoding)
 
 
 def clean_prefix(text: str, pattern: str, ignore_case: bool = False, strip: bool = True) -> str:
@@ -264,4 +379,5 @@ def bytes_string_to_string(text: str, encoding: str = "utf-8"):
     """Converts a string representation of a byte string to a regular string using the
     specified encoding."""
     text_bytes = bytes([ord(char) for char in text])
-    return text_bytes.decode(encoding)
+    formatted_encoding = format_encoding_str(encoding)
+    return text_bytes.decode(formatted_encoding)
