@@ -6,6 +6,7 @@ from unstructured.ingest.connector.fsspec import (
     FsspecIngestDoc,
     SimpleFsspecConfig,
 )
+from unstructured.ingest.interfaces import StandardConnectorConfig
 from unstructured.utils import requires_dependencies
 
 
@@ -14,7 +15,10 @@ class SimpleAzureBlobStorageConfig(SimpleFsspecConfig):
     pass
 
 
+@dataclass
 class AzureBlobStorageIngestDoc(FsspecIngestDoc):
+    registry_name: str = "azure"
+
     @requires_dependencies(["adlfs", "fsspec"], extras="azure")
     def get_file(self):
         super().get_file()
@@ -26,6 +30,7 @@ class AzureBlobStorageConnector(FsspecConnector):
 
     def __init__(
         self,
+        standard_config: StandardConnectorConfig,
         config: SimpleAzureBlobStorageConfig,
     ) -> None:
-        super().__init__(config=config)
+        super().__init__(standard_config=standard_config, config=config)
