@@ -1,10 +1,9 @@
-import json
 import os
 import urllib.request
 from dataclasses import dataclass
 from ftplib import FTP, error_perm
 from pathlib import Path
-from typing import List, Union
+from typing import List, Optional
 
 import requests
 from bs4 import BeautifulSoup
@@ -15,6 +14,8 @@ from unstructured.ingest.interfaces import (
     BaseConnector,
     BaseConnectorConfig,
     BaseIngestDoc,
+    ConnectorCleanupMixin,
+    IngestDocCleanupMixin,
     StandardConnectorConfig,
 )
 from unstructured.ingest.logger import logger
@@ -31,8 +32,8 @@ PDF_DIR = "oa_pdf"
 @dataclass
 class BiomedFileMeta:
     ftp_path: str
-    download_filepath: Union[str, os.PathLike]
-    output_filepath: Union[str, os.PathLike]
+    download_filepath: str
+    output_filepath: str
 
 
 @dataclass
@@ -40,11 +41,11 @@ class SimpleBiomedConfig(BaseConnectorConfig):
     """Connector config where path is the FTP directory path and
     id_, from_, until, format are API parameters."""
 
-    path: str
+    path: Optional[str]
     # OA Web Service API Options
-    id_: str
-    from_: str
-    until: str
+    id_: Optional[str]
+    from_: Optional[str]
+    until: Optional[str]
     max_retries: int = 5
     request_timeout: int = 45
     decay: float = 0.3
@@ -106,14 +107,16 @@ class SimpleBiomedConfig(BaseConnectorConfig):
 
 
 @dataclass
-class BiomedIngestDoc(BaseIngestDoc):
+class BiomedIngestDoc(IngestDocCleanupMixin, BaseIngestDoc):
     config: SimpleBiomedConfig
     file_meta: BiomedFileMeta
+    registry_name: str = "biomed"
 
     @property
     def filename(self):
         return Path(self.file_meta.download_filepath).resolve()  # type: ignore
 
+    @property
     def _output_filename(self):
         return Path(f"{self.file_meta.output_filepath}.json").resolve()
 
@@ -126,42 +129,23 @@ class BiomedIngestDoc(BaseIngestDoc):
             logger.debug(f"Cleaning up {self}")
             Path.unlink(self.filename)
 
-    def has_output(self):
-        """Determine if structured output for this doc already exists."""
-        output_filename = self._output_filename()
-        return output_filename.is_file() and output_filename.stat()
-
+    @BaseIngestDoc.skip_if_file_exists
     def get_file(self):
         download_path = self.file_meta.download_filepath  # type: ignore
-
         dir_ = Path(os.path.dirname(download_path))  # type: ignore
         if not dir_.is_dir():
             logger.debug(f"Creating directory: {dir_}")
 
             if dir_:
                 dir_.mkdir(parents=True, exist_ok=True)
-
         urllib.request.urlretrieve(
             self.file_meta.ftp_path,  # type: ignore
             self.file_meta.download_filepath,
         )
-
         logger.debug(f"File downloaded: {self.file_meta.download_filepath}")
 
-    def write_result(self):
-        """Write the structured json result for this doc. result must be json serializable."""
-        if self.standard_config.download_only:
-            return
-        output_filename = self._output_filename()
-        output_filename.parent.mkdir(parents=True, exist_ok=True)
-        with open(output_filename, "w") as output_f:
-            output_f.write(
-                json.dumps(self.isd_elems_no_filename, ensure_ascii=False, indent=2),
-            )
-        logger.info(f"Wrote {output_filename}")
 
-
-class BiomedConnector(BaseConnector):
+class BiomedConnector(ConnectorCleanupMixin, BaseConnector):
     """Objects of this class support fetching documents from Biomedical literature FTP directory"""
 
     config: SimpleBiomedConfig
@@ -172,9 +156,6 @@ class BiomedConnector(BaseConnector):
         config: SimpleBiomedConfig,
     ):
         super().__init__(standard_config, config)
-        self.cleanup_files = (
-            not self.standard_config.preserve_downloads and not self.standard_config.download_only
-        )
 
     def _list_objects_api(self):
         def urls_to_metadata(urls):
@@ -186,12 +167,12 @@ class BiomedConnector(BaseConnector):
                     files.append(
                         BiomedFileMeta(
                             ftp_path=url,
-                            download_filepath=(
-                                Path(self.standard_config.download_dir) / local_path
-                            ).resolve(),
-                            output_filepath=(
-                                Path(self.standard_config.output_dir) / local_path
-                            ).resolve(),
+                            download_filepath=(Path(self.standard_config.download_dir) / local_path)
+                            .resolve()
+                            .as_posix(),
+                            output_filepath=(Path(self.standard_config.output_dir) / local_path)
+                            .resolve()
+                            .as_posix(),
                         ),
                     )
 
@@ -237,6 +218,10 @@ class BiomedConnector(BaseConnector):
     def _list_objects(self):
         files = []
 
+        # Conform to mypy, null check performed elsewhere.
+        # Wouldn't be in this method unless self.config.path exists
+        path: str = self.config.path if self.config.path else ""
+
         def traverse(path, download_dir, output_dir):
             full_path = Path(PMC_DIR) / path
             logger.debug(f"Traversing directory: {full_path}")
@@ -265,10 +250,12 @@ class BiomedConnector(BaseConnector):
                                 ftp_path=ftp_path,
                                 download_filepath=(
                                     Path(self.standard_config.download_dir) / local_path
-                                ).resolve(),
-                                output_filepath=(
-                                    Path(self.standard_config.output_dir) / local_path
-                                ).resolve(),
+                                )
+                                .resolve()
+                                .as_posix(),
+                                output_filepath=(Path(self.standard_config.output_dir) / local_path)
+                                .resolve()
+                                .as_posix(),
                             ),
                         )
 
@@ -281,45 +268,27 @@ class BiomedConnector(BaseConnector):
 
         ftp_path = f"{FTP_DOMAIN}/{PMC_DIR}/{self.config.path}"
         if self.config.is_file:
-            local_path = "/".join(self.config.path.split("/")[1:])
+            local_path = "/".join(path.split("/")[1:])
             return [
                 BiomedFileMeta(
                     ftp_path=ftp_path,
-                    download_filepath=(
-                        Path(self.standard_config.download_dir) / local_path
-                    ).resolve(),
-                    output_filepath=(Path(self.standard_config.output_dir) / local_path).resolve(),
+                    download_filepath=(Path(self.standard_config.download_dir) / local_path)
+                    .resolve()
+                    .as_posix(),
+                    output_filepath=(Path(self.standard_config.output_dir) / local_path)
+                    .resolve()
+                    .as_posix(),
                 ),
             ]
         else:
             traverse(
-                Path(self.config.path),
+                Path(path),
                 Path(self.standard_config.download_dir),
                 Path(self.standard_config.output_dir),
             )
 
         return files
 
-    def cleanup(self, cur_dir=None):
-        if not self.cleanup_files:
-            return
-
-        if cur_dir is None:
-            cur_dir = self.standard_config.download_dir
-
-        if cur_dir is None or not Path(cur_dir).is_dir():
-            return
-
-        sub_dirs = os.listdir(cur_dir)
-        os.chdir(cur_dir)
-        for sub_dir in sub_dirs:
-            # don't traverse symlinks, not that there every should be any
-            if os.path.isdir(sub_dir) and not os.path.islink(sub_dir):
-                self.cleanup(sub_dir)
-        os.chdir("..")
-        if len(os.listdir(cur_dir)) == 0:
-            os.rmdir(cur_dir)
-
     def initialize(self):
         pass
 
