@@ -1,6 +1,5 @@
 import fnmatch
 import glob
-import json
 import os
 from dataclasses import dataclass
 from pathlib import Path
@@ -37,6 +36,7 @@ class LocalIngestDoc(BaseIngestDoc):
 
     config: SimpleLocalConfig
     path: str
+    registry_name: str = "local"
 
     @property
     def filename(self):
@@ -51,25 +51,19 @@ class LocalIngestDoc(BaseIngestDoc):
         """Not applicable to local file system"""
         pass
 
-    def _output_filename(self):
-        return (
-            Path(self.standard_config.output_dir)
-            / f"{self.path.replace(f'{self.config.input_path}/', '')}.json"
+    @property
+    def _output_filename(self) -> Path:
+        """Returns output filename for the doc
+        If input path argument is a file itself, it returns the filename of the doc.
+        If input path argument is a folder, it returns the relative path of the doc.
+        """
+        input_path = Path(self.config.input_path)
+        basename = (
+            f"{Path(self.path).name}.json"
+            if input_path.is_file()
+            else f"{Path(self.path).relative_to(input_path)}.json"
         )
-
-    def has_output(self):
-        """Determine if structured output for this doc already exists."""
-        return self._output_filename().is_file() and os.path.getsize(self._output_filename())
-
-    def write_result(self):
-        """Write the structured json result for this doc. result must be json serializable."""
-        if self.standard_config.download_only:
-            return
-        output_filename = self._output_filename()
-        output_filename.parent.mkdir(parents=True, exist_ok=True)
-        with open(output_filename, "w") as output_f:
-            output_f.write(json.dumps(self.isd_elems_no_filename, ensure_ascii=False, indent=2))
-        logger.info(f"Wrote {output_filename}")
+        return Path(self.standard_config.output_dir) / basename
 
 
 class LocalConnector(BaseConnector):
