@@ -6,6 +6,7 @@ from unstructured.ingest.connector.fsspec import (
     FsspecIngestDoc,
     SimpleFsspecConfig,
 )
+from unstructured.ingest.interfaces import StandardConnectorConfig
 from unstructured.utils import requires_dependencies
 
 
@@ -14,7 +15,11 @@ class SimpleS3Config(SimpleFsspecConfig):
     pass
 
 
+@dataclass
 class S3IngestDoc(FsspecIngestDoc):
+    remote_file_path: str
+    registry_name: str = "s3"
+
     @requires_dependencies(["s3fs", "fsspec"], extras="s3")
     def get_file(self):
         super().get_file()
@@ -27,5 +32,6 @@ class S3Connector(FsspecConnector):
     def __init__(
         self,
         config: SimpleS3Config,
+        standard_config: StandardConnectorConfig,
     ) -> None:
-        super().__init__(config=config)
+        super().__init__(standard_config, config)
