@@ -1,17 +1,16 @@
-import json
 import os
+import xml.etree.ElementTree as ET
 from dataclasses import dataclass
 from datetime import datetime
 from pathlib import Path
-from typing import List
-
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
+from typing import List, Optional
 
 from unstructured.ingest.interfaces import (
     BaseConnector,
     BaseConnectorConfig,
     BaseIngestDoc,
+    ConnectorCleanupMixin,
+    IngestDocCleanupMixin,
     StandardConnectorConfig,
 )
 from unstructured.ingest.logger import logger
@@ -29,8 +28,8 @@ class SimpleSlackConfig(BaseConnectorConfig):
 
     channels: List[str]
     token: str
-    oldest: str
-    latest: str
+    oldest: Optional[str]
+    latest: Optional[str]
     verbose: bool = False
 
     def validate_inputs(self):
@@ -59,7 +58,7 @@ class SimpleSlackConfig(BaseConnectorConfig):
 
 
 @dataclass
-class SlackIngestDoc(BaseIngestDoc):
+class SlackIngestDoc(IngestDocCleanupMixin, BaseIngestDoc):
     """Class encapsulating fetching a doc and writing processed results (but not
     doing the processing!).
 
@@ -70,45 +69,38 @@ class SlackIngestDoc(BaseIngestDoc):
     config: SimpleSlackConfig
     channel: str
     token: str
-    oldest: str
-    latest: str
+    oldest: Optional[str]
+    latest: Optional[str]
+    registry_name: str = "slack"
 
     # NOTE(crag): probably doesn't matter,  but intentionally not defining tmp_download_file
     # __post_init__ for multiprocessing simplicity (no Path objects in initially
     # instantiated object)
     def _tmp_download_file(self):
-        channel_file = self.channel + ".txt"
+        channel_file = self.channel + ".xml"
         return Path(self.standard_config.download_dir) / channel_file
 
+    @property
     def _output_filename(self):
         output_file = self.channel + ".json"
         return Path(self.standard_config.output_dir) / output_file
 
-    def has_output(self):
-        """Determine if structured output for this doc already exists."""
-        return self._output_filename().is_file() and os.path.getsize(self._output_filename())
-
     def _create_full_tmp_dir_path(self):
         self._tmp_download_file().parent.mkdir(parents=True, exist_ok=True)
 
+    @BaseIngestDoc.skip_if_file_exists
     @requires_dependencies(dependencies=["slack_sdk"], extras="slack")
     def get_file(self):
+        from slack_sdk import WebClient
+        from slack_sdk.errors import SlackApiError
+
         """Fetches the data from a slack channel and stores it locally."""
 
         self._create_full_tmp_dir_path()
-        if (
-            not self.standard_config.re_download
-            and self._tmp_download_file().is_file()
-            and os.path.getsize(self._tmp_download_file())
-        ):
-            if self.config.verbose:
-                logger.debug(f"File exists: {self._tmp_download_file()}, skipping download")
-            return
 
         if self.config.verbose:
             logger.debug(f"fetching channel {self.channel} - PID: {os.getpid()}")
 
-        messages = []
         self.client = WebClient(token=self.token)
 
         try:
@@ -125,29 +117,39 @@ class SlackIngestDoc(BaseIngestDoc):
                 oldest=oldest,
                 latest=latest,
             )
-            messages.extend(result["messages"])
-            while result["has_more"]:
-                result = self.client.conversations_history(
-                    channel=self.channel,
-                    oldest=oldest,
-                    latest=latest,
-                    cursor=result["response_metadata"]["next_cursor"],
-                )
-                messages.extend(result["messages"])
+
+            root = ET.Element("messages")
+            for message in result["messages"]:
+                message_elem = ET.SubElement(root, "message")
+                text_elem = ET.SubElement(message_elem, "text")
+                text_elem.text = message.get("text")
+
+                cursor = None
+                while True:
+                    try:
+                        response = self.client.conversations_replies(
+                            channel=self.channel,
+                            ts=message["ts"],
+                            cursor=cursor,
+                        )
+
+                        for reply in response["messages"]:
+                            reply_msg = reply.get("text")
+                            text_elem.text = "".join([str(text_elem.text), " <reply> ", reply_msg])
+
+                        if not response["has_more"]:
+                            break
+
+                        cursor = response["response_metadata"]["next_cursor"]
+
+                    except SlackApiError as e:
+                        print(f"Error retrieving replies: {e.response['error']}")
+
         except SlackApiError as e:
             logger.error(f"Error: {e}")
 
-        with open(self._tmp_download_file(), "w") as channel_file:
-            for message in messages:
-                channel_file.write(message["text"] + "\n")
-
-    def write_result(self):
-        """Write the structured json result for this doc. result must be json serializable."""
-        output_filename = self._output_filename()
-        output_filename.parent.mkdir(parents=True, exist_ok=True)
-        with open(output_filename, "w") as output_f:
-            output_f.write(json.dumps(self.isd_elems_no_filename, ensure_ascii=False, indent=2))
-        logger.info(f"Wrote {output_filename}")
+        tree = ET.ElementTree(root)
+        tree.write(self._tmp_download_file(), encoding="utf-8", xml_declaration=True)
 
     def convert_datetime(self, date_time):
         for format in DATE_FORMATS:
@@ -161,41 +163,15 @@ class SlackIngestDoc(BaseIngestDoc):
         """The filename of the file created from a slack channel"""
         return self._tmp_download_file()
 
-    def cleanup_file(self):
-        """Removes the local copy the file after successful processing."""
-        if not self.standard_config.preserve_downloads:
-            if self.config.verbose:
-                logger.info(f"cleaning up channel {self.channel}")
-            os.unlink(self._tmp_download_file())
-
 
 @requires_dependencies(dependencies=["slack_sdk"], extras="slack")
-class SlackConnector(BaseConnector):
+class SlackConnector(ConnectorCleanupMixin, BaseConnector):
     """Objects of this class support fetching document(s) from"""
 
     config: SimpleSlackConfig
 
     def __init__(self, standard_config: StandardConnectorConfig, config: SimpleSlackConfig):
         super().__init__(standard_config, config)
-        self.cleanup_files = not standard_config.preserve_downloads
-
-    def cleanup(self, cur_dir=None):
-        """cleanup linginering empty sub-dirs, but leave remaining files
-        (and their paths) in tact as that indicates they were not processed"""
-        if not self.cleanup_files:
-            return
-
-        if cur_dir is None:
-            cur_dir = self.standard_config.download_dir
-        sub_dirs = os.listdir(cur_dir)
-        os.chdir(cur_dir)
-        for sub_dir in sub_dirs:
-            # don't traverse symlinks, not that there every should be any
-            if os.path.isdir(sub_dir) and not os.path.islink(sub_dir):
-                self.cleanup(sub_dir)
-        os.chdir("..")
-        if len(os.listdir(cur_dir)) == 0:
-            os.rmdir(cur_dir)
 
     def initialize(self):
         """Verify that can get metadata for an object, validates connections info."""
