@@ -1,4 +1,3 @@
-import json
 import os
 from dataclasses import dataclass, field
 from pathlib import Path
@@ -8,9 +7,12 @@ from unstructured.ingest.interfaces import (
     BaseConnector,
     BaseConnectorConfig,
     BaseIngestDoc,
+    ConnectorCleanupMixin,
+    IngestDocCleanupMixin,
     StandardConnectorConfig,
 )
 from unstructured.ingest.logger import logger
+from unstructured.utils import requires_dependencies
 
 if TYPE_CHECKING:
     from wikipedia import WikipediaPage
@@ -23,9 +25,18 @@ class SimpleWikipediaConfig(BaseConnectorConfig):
 
 
 @dataclass
-class WikipediaIngestDoc(BaseIngestDoc):
+class WikipediaIngestDoc(IngestDocCleanupMixin, BaseIngestDoc):
     config: SimpleWikipediaConfig = field(repr=False)
-    page: "WikipediaPage"
+
+    @property
+    @requires_dependencies(["wikipedia"], extras="wikipedia")
+    def page(self) -> "WikipediaPage":
+        import wikipedia
+
+        return wikipedia.page(
+            self.config.title,
+            auto_suggest=self.config.auto_suggest,
+        )
 
     @property
     def filename(self) -> Path:
@@ -35,50 +46,26 @@ class WikipediaIngestDoc(BaseIngestDoc):
     def text(self) -> str:
         raise NotImplementedError()
 
+    @property
     def _output_filename(self):
         raise NotImplementedError()
 
     def _create_full_tmp_dir_path(self):
         self.filename.parent.mkdir(parents=True, exist_ok=True)
 
-    def cleanup_file(self):
-        """Removes the local copy of the file (or anything else) after successful processing."""
-        if not self.standard_config.preserve_downloads and not self.standard_config.download_only:
-            logger.debug(f"Cleaning up {self}")
-            os.unlink(self.filename)
-
+    @BaseIngestDoc.skip_if_file_exists
     def get_file(self):
         """Fetches the "remote" doc and stores it locally on the filesystem."""
         self._create_full_tmp_dir_path()
-        if (
-            not self.standard_config.re_download
-            and self.filename.is_file()
-            and self.filename.stat()
-        ):
-            logger.debug(f"File exists: {self.filename}, skipping download")
-            return
-
         logger.debug(f"Fetching {self} - PID: {os.getpid()}")
         with open(self.filename, "w", encoding="utf8") as f:
             f.write(self.text)
 
-    def has_output(self):
-        """Determine if structured output for this doc already exists."""
-        output_filename = self._output_filename()
-        return output_filename.is_file() and output_filename.stat()
-
-    def write_result(self):
-        """Write the structured json result for this doc. result must be json serializable."""
-        if self.standard_config.download_only:
-            return
-        output_filename = self._output_filename()
-        output_filename.parent.mkdir(parents=True, exist_ok=True)
-        with open(output_filename, "w", encoding="utf8") as output_f:
-            json.dump(self.isd_elems_no_filename, output_f, ensure_ascii=False, indent=2)
-        logger.info(f"Wrote {output_filename}")
-
 
+@dataclass
 class WikipediaIngestHTMLDoc(WikipediaIngestDoc):
+    registry_name: str = "wikipedia_html"
+
     @property
     def filename(self) -> Path:
         return (
@@ -90,6 +77,7 @@ class WikipediaIngestHTMLDoc(WikipediaIngestDoc):
     def text(self):
         return self.page.html()
 
+    @property
     def _output_filename(self):
         return (
             Path(self.standard_config.output_dir)
@@ -97,7 +85,10 @@ class WikipediaIngestHTMLDoc(WikipediaIngestDoc):
         )
 
 
+@dataclass
 class WikipediaIngestTextDoc(WikipediaIngestDoc):
+    registry_name: str = "wikipedia_text"
+
     @property
     def filename(self) -> Path:
         return (
@@ -109,6 +100,7 @@ class WikipediaIngestTextDoc(WikipediaIngestDoc):
     def text(self):
         return self.page.content
 
+    @property
     def _output_filename(self):
         return (
             Path(self.standard_config.output_dir)
@@ -116,7 +108,10 @@ class WikipediaIngestTextDoc(WikipediaIngestDoc):
         )
 
 
+@dataclass
 class WikipediaIngestSummaryDoc(WikipediaIngestDoc):
+    registry_name: str = "wikipedia_summary"
+
     @property
     def filename(self) -> Path:
         return (
@@ -128,6 +123,7 @@ class WikipediaIngestSummaryDoc(WikipediaIngestDoc):
     def text(self):
         return self.page.summary
 
+    @property
     def _output_filename(self):
         return (
             Path(self.standard_config.output_dir)
@@ -135,43 +131,18 @@ class WikipediaIngestSummaryDoc(WikipediaIngestDoc):
         )
 
 
-class WikipediaConnector(BaseConnector):
+class WikipediaConnector(ConnectorCleanupMixin, BaseConnector):
     config: SimpleWikipediaConfig
 
     def __init__(self, config: SimpleWikipediaConfig, standard_config: StandardConnectorConfig):
         super().__init__(standard_config, config)
-        self.cleanup_files = (
-            not standard_config.preserve_downloads and not standard_config.download_only
-        )
-
-    def cleanup(self, cur_dir=None):
-        if not self.cleanup_files:
-            return
-
-        if cur_dir is None:
-            cur_dir = self.standard_config.download_dir
-        sub_dirs = os.listdir(cur_dir)
-        os.chdir(cur_dir)
-        for sub_dir in sub_dirs:
-            # don't traverse symlinks, not that there every should be any
-            if os.path.isdir(sub_dir) and not os.path.islink(sub_dir):
-                self.cleanup(sub_dir)
-        os.chdir("..")
-        if len(os.listdir(cur_dir)) == 0:
-            os.rmdir(cur_dir)
 
     def initialize(self):
         pass
 
     def get_ingest_docs(self):
-        import wikipedia
-
-        page = wikipedia.page(
-            self.config.title,
-            auto_suggest=self.config.auto_suggest,
-        )
         return [
-            WikipediaIngestTextDoc(self.standard_config, self.config, page),
-            WikipediaIngestHTMLDoc(self.standard_config, self.config, page),
-            WikipediaIngestSummaryDoc(self.standard_config, self.config, page),
+            WikipediaIngestTextDoc(self.standard_config, self.config),
+            WikipediaIngestHTMLDoc(self.standard_config, self.config),
+            WikipediaIngestSummaryDoc(self.standard_config, self.config),
         ]
