@@ -8,6 +8,7 @@ from typing import (
 import requests
 
 from unstructured.documents.elements import Element
+from unstructured.logger import logger
 from unstructured.partition.common import exactly_one
 from unstructured.staging.base import dict_to_elements, elements_from_json
 
@@ -15,10 +16,11 @@ from unstructured.staging.base import dict_to_elements, elements_from_json
 def partition_via_api(
     filename: Optional[str] = None,
     content_type: Optional[str] = None,
-    file: Optional[IO] = None,
+    file: Optional[IO[bytes]] = None,
     file_filename: Optional[str] = None,
     api_url: str = "https://api.unstructured.io/general/v0/general",
     api_key: str = "",
+    metadata_filename: Optional[str] = None,
     **request_kwargs,
 ) -> List[Element]:
     """Partitions a document using the Unstructured REST API. This is equivalent to
@@ -36,7 +38,7 @@ def partition_via_api(
         A string defining the file content in MIME type
     file
         A file-like object using "rb" mode --> open(filename, "rb").
-    file_filename
+    metadata_filename
         When file is not None, the filename (string) to store in element metadata. E.g. "foo.txt"
     api_url
         The URL for the Unstructured API. Defaults to the hosted Unstructured API.
@@ -48,15 +50,24 @@ def partition_via_api(
     """
     exactly_one(filename=filename, file=file)
 
+    if metadata_filename and file_filename:
+        raise ValueError(
+            "Only one of metadata_filename and file_filename is specified. "
+            "metadata_filename is preferred. file_filename is marked for deprecation.",
+        )
+
+    if file_filename is not None:
+        metadata_filename = file_filename
+        logger.warn(
+            "The file_filename kwarg will be deprecated in a future version of unstructured. "
+            "Please use metadata_filename instead.",
+        )
+
     headers = {
         "ACCEPT": "application/json",
         "UNSTRUCTURED-API-KEY": api_key,
     }
 
-    # set default values for kwargs
-    strategy = request_kwargs.pop("strategy", "hi_res")
-    request_kwargs["strategy"] = strategy
-
     if filename is not None:
         with open(filename, "rb") as f:
             files = [
@@ -69,13 +80,13 @@ def partition_via_api(
                 files=files,  # type: ignore
             )
     elif file is not None:
-        if file_filename is None:
+        if metadata_filename is None:
             raise ValueError(
                 "If file is specified in partition_via_api, "
-                "file_filename must be specified as well.",
+                "metadata_filename must be specified as well.",
             )
         files = [
-            ("files", (file_filename, file, content_type)),  # type: ignore
+            ("files", (metadata_filename, file, content_type)),  # type: ignore
         ]
         response = requests.post(
             api_url,
@@ -99,6 +110,7 @@ def partition_multiple_via_api(
     file_filenames: Optional[List[str]] = None,
     api_url: str = "https://api.unstructured.io/general/v0/general",
     api_key: str = "",
+    metadata_filenames: Optional[List[str]] = None,
     **request_kwargs,
 ) -> List[List[Element]]:
     """Partitions multiple document using the Unstructured REST API by batching
@@ -110,18 +122,14 @@ def partition_multiple_via_api(
 
     Parameters
     ----------
-    filename
+    filenames
         A list of strings defining the target filename paths.
     content_types
         A list of strings defining the file contents in MIME types.
     files
         A list of file-like object using "rb" mode --> open(filename, "rb").
-    file_filename
+    metadata_filename
         When file is not None, the filename (string) to store in element metadata. E.g. "foo.txt"
-    strategy
-        The strategy to use for partitioning the PDF. Uses a layout detection model if set
-        to 'hi_res', otherwise partition_pdf simply extracts the text from the document
-        and processes it.
     api_url
         The URL for the Unstructured API. Defaults to the hosted Unstructured API.
     api_key
@@ -135,9 +143,18 @@ def partition_multiple_via_api(
         "UNSTRUCTURED-API-KEY": api_key,
     }
 
-    # set default values for kwargs
-    strategy = request_kwargs.pop("strategy", "hi_res")
-    request_kwargs["strategy"] = strategy
+    if metadata_filenames and file_filenames:
+        raise ValueError(
+            "Only one of metadata_filenames and file_filenames is specified. "
+            "metadata_filenames is preferred. file_filenames is marked for deprecation.",
+        )
+
+    if file_filenames is not None:
+        metadata_filenames = file_filenames
+        logger.warn(
+            "The file_filenames kwarg will be deprecated in a future version of unstructured. "
+            "Please use metadata_filenames instead.",
+        )
 
     if filenames is not None:
         if content_types and len(content_types) != len(filenames):
@@ -163,15 +180,15 @@ def partition_multiple_via_api(
         if content_types and len(content_types) != len(files):
             raise ValueError("content_types and files must have the same length.")
 
-        if not file_filenames:
-            raise ValueError("file_filenames must be specified if files are passed")
-        elif len(file_filenames) != len(files):
-            raise ValueError("file_filenames and files must have the same length.")
+        if not metadata_filenames:
+            raise ValueError("metadata_filenames must be specified if files are passed")
+        elif len(metadata_filenames) != len(files):
+            raise ValueError("metadata_filenames and files must have the same length.")
 
         _files = []
         for i, _file in enumerate(files):  # type: ignore
             content_type = content_types[i] if content_types is not None else None
-            filename = file_filenames[i]
+            filename = metadata_filenames[i]
             _files.append(("files", (filename, _file, content_type)))
 
         response = requests.post(
