@@ -1,4 +1,4 @@
-from typing import IO, Dict, List, Optional
+from typing import IO, TYPE_CHECKING, Dict, List, Optional
 
 import requests
 
@@ -10,18 +10,23 @@ from unstructured.file_utils.file_conversion import convert_file_to_html_text
 from unstructured.file_utils.filetype import (
     FileType,
     add_metadata_with_filetype,
-    document_to_element_list,
 )
 from unstructured.partition.common import (
+    document_to_element_list,
     exactly_one,
+    get_last_modified_date,
+    get_last_modified_date_from_file,
 )
 
+if TYPE_CHECKING:
+    from unstructured_inference.inference.layout import DocumentLayout
+
 
 @process_metadata()
 @add_metadata_with_filetype(FileType.HTML)
 def partition_html(
     filename: Optional[str] = None,
-    file: Optional[IO] = None,
+    file: Optional[IO[bytes]] = None,
     text: Optional[str] = None,
     url: Optional[str] = None,
     encoding: Optional[str] = None,
@@ -30,13 +35,17 @@ def partition_html(
     headers: Dict[str, str] = {},
     ssl_verify: bool = True,
     parser: VALID_PARSERS = None,
+    html_assemble_articles: bool = False,
+    metadata_filename: Optional[str] = None,
+    metadata_last_modified: Optional[str] = None,
+    skip_headers_and_footers: bool = False,
     **kwargs,
 ) -> List[Element]:
     """Partitions an HTML document into its constituent elements.
 
     Parameters
     ----------
-     filename
+    filename
         A string defining the target filename path.
     file
         A file-like object using "r" mode --> open(filename, "r").
@@ -58,23 +67,43 @@ def partition_html(
         in the HTTP request.
     parser
         The parser to use for parsing the HTML document. If None, default parser will be used.
+    metadata_last_modified
+        The last modified date for the document.
+    skip_headers_and_footers
+        If True, ignores any content that is within <header> or <footer> tags
+
     """
     if text is not None and text.strip() == "" and not file and not filename and not url:
         return []
-
     # Verify that only one of the arguments was provided
     exactly_one(filename=filename, file=file, text=text, url=url)
 
+    last_modification_date = None
     if filename is not None:
-        document = HTMLDocument.from_file(filename, parser=parser, encoding=encoding)
+        last_modification_date = get_last_modified_date(filename)
+        document = HTMLDocument.from_file(
+            filename,
+            parser=parser,
+            encoding=encoding,
+            assemble_articles=html_assemble_articles,
+        )
 
     elif file is not None:
+        last_modification_date = get_last_modified_date_from_file(file)
         _, file_text = read_txt_file(file=file, encoding=encoding)
-        document = HTMLDocument.from_string(file_text, parser=parser)
+        document = HTMLDocument.from_string(
+            file_text,
+            parser=parser,
+            assemble_articles=html_assemble_articles,
+        )
 
     elif text is not None:
         _text: str = str(text)
-        document = HTMLDocument.from_string(_text, parser=parser)
+        document = HTMLDocument.from_string(
+            _text,
+            parser=parser,
+            assemble_articles=html_assemble_articles,
+        )
 
     elif url is not None:
         response = requests.get(url, headers=headers, verify=ssl_verify)
@@ -87,14 +116,25 @@ def partition_html(
 
         document = HTMLDocument.from_string(response.text, parser=parser)
 
-    return document_to_element_list(document, include_page_breaks=include_page_breaks)
+    if skip_headers_and_footers:
+        document = filter_footer_and_header(document)
+
+    return document_to_element_list(
+        document,
+        sortable=False,
+        include_page_breaks=include_page_breaks,
+        last_modification_date=metadata_last_modified or last_modification_date,
+        **kwargs,
+    )
 
 
 def convert_and_partition_html(
     source_format: str,
     filename: Optional[str] = None,
-    file: Optional[IO] = None,
+    file: Optional[IO[bytes]] = None,
     include_page_breaks: bool = False,
+    metadata_filename: Optional[str] = None,
+    metadata_last_modified: Optional[str] = None,
 ) -> List[Element]:
     """Converts a document to HTML and then partitions it using partition_html. Works with
     any file format support by pandoc.
@@ -107,15 +147,41 @@ def convert_and_partition_html(
         A string defining the target filename path.
     file
         A file-like object using "rb" mode --> open(filename, "rb").
-
     include_page_breaks
-        If True, the output will include page breaks if the filetype supports it
+        If True, the output will include page breaks if the filetype supports it.
+    metadata_filename
+        The filename to use in element metadata.
+    metadata_last_modified
+        The last modified date for the document.
     """
-    html_text = convert_file_to_html_text(source_format=source_format, filename=filename, file=file)
+
+    last_modification_date = None
+    if filename:
+        last_modification_date = get_last_modified_date(filename)
+    elif file:
+        last_modification_date = get_last_modified_date_from_file(file)
+    html_text = convert_file_to_html_text(
+        source_format=source_format,
+        filename=filename,
+        file=file,
+    )
     # NOTE(robinson) - pypandoc returns a text string with unicode encoding
     # ref: https://github.com/JessicaTegner/pypandoc#usage
     return partition_html(
         text=html_text,
         include_page_breaks=include_page_breaks,
         encoding="unicode",
+        metadata_filename=metadata_filename,
+        metadata_last_modified=metadata_last_modified or last_modification_date,
     )
+
+
+def filter_footer_and_header(document: "DocumentLayout") -> "DocumentLayout":
+    for page in document.pages:
+        page.elements = list(
+            filter(
+                lambda el: "footer" not in el.ancestortags and "header" not in el.ancestortags,
+                page.elements,
+            ),
+        )
+    return document
