@@ -9,12 +9,11 @@ from unstructured.partition.pdf import partition_pdf_or_image
 def partition_image(
     filename: str = "",
     file: Optional[bytes] = None,
-    url: Optional[str] = None,
-    template: Optional[str] = None,
-    token: Optional[str] = None,
     include_page_breaks: bool = False,
+    infer_table_structure: bool = False,
     ocr_languages: str = "eng",
-    strategy: str = "auto",
+    strategy: str = "hi_res",
+    metadata_last_modified: Optional[str] = None,
     **kwargs,
 ) -> List[Element]:
     """Parses an image into a list of interpreted elements.
@@ -25,14 +24,15 @@ def partition_image(
         A string defining the target filename path.
     file
         A file-like object as bytes --> open(filename, "rb").
-    template
-        A string defining the model to be used. Default None uses default model ("layout/image" url
-        if using the API).
-    url
-        A string endpoint to self-host an inference API, if desired. If None, local inference will
-        be used.
-    token
-        A string defining the authentication token for a self-host url, if applicable.
+    include_page_breaks
+        If True, includes page breaks at the end of each page in the document.
+    infer_table_structure
+        Only applicable if `strategy=hi_res`.
+        If True, any Table elements that are extracted will also have a metadata field
+        named "text_as_html" where the table's text content is rendered into an html string.
+        I.e., rows and cells are preserved.
+        Whether True or False, the "text" field is always present in any Table element
+        and is the text content of the table (no structure).
     ocr_languages
         The languages to use for the Tesseract agent. To use a language, you'll first need
         to install the appropriate Tesseract language pack.
@@ -41,21 +41,21 @@ def partition_image(
         "ocr_only". When using the "hi_res" strategy, the function uses a layout detection
         model if to identify document elements. When using the "ocr_only" strategy,
         partition_image simply extracts the text from the document using OCR and processes it.
-        The default strategy `auto` will determine when a image can be extracted using
-        `ocr_only` mode, otherwise it will fall back to `hi_res`.
+        The default strategy is `hi_res`.
+    metadata_last_modified
+        The last modified date for the document.
+
+
     """
     exactly_one(filename=filename, file=file)
 
-    if template is None:
-        template = "layout/image"
-
     return partition_pdf_or_image(
         filename=filename,
         file=file,
-        url=url,
-        template=template,
-        token=token,
+        is_image=True,
         include_page_breaks=include_page_breaks,
+        infer_table_structure=infer_table_structure,
         ocr_languages=ocr_languages,
         strategy=strategy,
+        metadata_last_modified=metadata_last_modified,
     )
