@@ -9,12 +9,15 @@ from unstructured.partition.html import convert_and_partition_html
 @add_metadata_with_filetype(FileType.RTF)
 def partition_rtf(
     filename: Optional[str] = None,
-    file: Optional[IO] = None,
+    file: Optional[IO[bytes]] = None,
     include_page_breaks: bool = False,
+    include_metadata: bool = True,
+    metadata_filename: Optional[str] = None,
+    metadata_last_modified: Optional[str] = None,
     **kwargs,
 ) -> List[Element]:
     """Partitions an RTF document. The document is first converted to HTML and then
-    partitioned using partiton_html.
+    partitioned using partition_html.
 
     Parameters
     ----------
@@ -24,10 +27,14 @@ def partition_rtf(
         A file-like object using "rb" mode --> open(filename, "rb").
     include_page_breaks
         If True, the output will include page breaks if the filetype supports it
+    metadata_last_modified
+        The last modified date for the document.
     """
     return convert_and_partition_html(
         source_format="rtf",
         filename=filename,
         file=file,
         include_page_breaks=include_page_breaks,
+        metadata_filename=metadata_filename,
+        metadata_last_modified=metadata_last_modified,
     )
