@@ -1,11 +1,7 @@
 from tempfile import SpooledTemporaryFile
-from typing import BinaryIO, Dict, List, Optional, Union, cast
-
-from pdfminer.pdfpage import PDFPage, PDFTextExtractionNotAllowed
-from pdfminer.utils import open_filename
+from typing import BinaryIO, Dict, List, Optional, Union
 
 from unstructured.logger import logger
-from unstructured.partition.common import exactly_one
 from unstructured.utils import dependency_exists
 
 VALID_STRATEGIES: Dict[str, List[str]] = {
@@ -36,37 +32,13 @@ def validate_strategy(strategy: str, filetype: str):
         raise ValueError(f"{strategy} is not a valid strategy for filetype {filetype}.")
 
 
-def is_pdf_text_extractable(
-    filename: str = "",
-    file: Optional[Union[bytes, BinaryIO, SpooledTemporaryFile]] = None,
-):
-    """Checks to see if the text from a PDF document is extractable. Sometimes the
-    text is not extractable due to PDF security settings."""
-    exactly_one(filename=filename, file=file)
-
-    def _fp_is_extractable(fp):
-        try:
-            next(PDFPage.get_pages(fp, check_extractable=True))
-            extractable = True
-        except PDFTextExtractionNotAllowed:
-            extractable = False
-        return extractable
-
-    if filename:
-        with open_filename(filename, "rb") as fp:
-            fp = cast(BinaryIO, fp)
-            return _fp_is_extractable(fp)
-    elif file:
-        fp = cast(BinaryIO, file)
-        return _fp_is_extractable(fp)
-
-
 def determine_pdf_or_image_strategy(
     strategy: str,
     filename: str = "",
     file: Optional[Union[bytes, BinaryIO, SpooledTemporaryFile]] = None,
     is_image: bool = False,
     infer_table_structure: bool = False,
+    pdf_text_extractable: bool = True,
 ):
     """Determines what strategy to use for processing PDFs or images, accounting for fallback
     logic if some dependencies are not available."""
@@ -75,19 +47,17 @@ def determine_pdf_or_image_strategy(
 
     if is_image:
         # Note(yuming): There is no fast strategy for images,
-        # use ocr_only as a fallback plan for consistency with PDFs.
-        # This can be removed once unstructured-api use auto as the default strategy.
+        # use hi_res as a fallback plan since it is the auto default.
         if strategy == "fast":
-            strategy = "ocr_only"
+            strategy = "hi_res"
         validate_strategy(strategy, "image")
         pdf_text_extractable = False
     else:
         validate_strategy(strategy, "pdf")
-        pdf_text_extractable = is_pdf_text_extractable(filename=filename, file=file)
 
     if strategy == "auto":
         if is_image:
-            strategy = _determine_image_auto_strategy(infer_table_structure=infer_table_structure)
+            strategy = _determine_image_auto_strategy()
         else:
             strategy = _determine_pdf_auto_strategy(
                 pdf_text_extractable=pdf_text_extractable,
@@ -144,13 +114,11 @@ def determine_pdf_or_image_strategy(
     return strategy
 
 
-def _determine_image_auto_strategy(infer_table_structure: bool = False):
+def _determine_image_auto_strategy():
     """If "auto" is passed in as the strategy, determines what strategy to use
     for images."""
-    if infer_table_structure is True:
-        return "hi_res"
-    else:
-        return "ocr_only"
+    # Use hi_res as the only default since images are only about one page
+    return "hi_res"
 
 
 def _determine_pdf_auto_strategy(
