@@ -35,7 +35,7 @@ def requires_dependencies(
                 raise ImportError(
                     f"Following dependencies are missing: {', '.join(missing_deps)}. "
                     + (
-                        f"Please install them using `pip install unstructured[{extras}]`."
+                        f"""Please install them using `pip install "unstructured[{extras}]"`."""
                         if extras
                         else f"Please install them using `pip install {' '.join(missing_deps)}`."
                     ),
@@ -50,8 +50,10 @@ def requires_dependencies(
 def dependency_exists(dependency):
     try:
         importlib.import_module(dependency)
-    except ImportError:
-        return False
+    except ImportError as e:
+        # Check to make sure this isn't some unrelated import error.
+        if dependency in repr(e):
+            return False
     return True
 
 
